/* fts-flatcurve-config.h.  Generated from fts-flatcurve-config.h.in by configure.  */
#define FTS_FLATCURVE_NAME "Dovecot FTS Flatcurve"
#define FTS_FLATCURVE_VERSION "1.x"
#define HAVE_FTS_MAIL_USER_INIT_2_3_17 /**/
#define XAPIAN_HAS_COMPACT 1
